@@ -1,8 +1,9 @@
-__VERSION__ = '0.1.1'
+__VERSION__ = '1.0'
 
 from django.conf import settings
+from django.core.exceptions import ImproperlyConfigured
 
 try:
     settings.INSTALLED_APPS = tuple(settings.INSTALLED_APPS + ('sorl.thumbnail',))
-except ImportError, e:
+except (ImportError, ImproperlyConfigured), e:
     pass
\ No newline at end of file
