@@ -43,4 +43,9 @@ class ThumbAdmin(ModelAdmin):
 
         self.list_display = tuple(result)
 
-        return super(ThumbAdmin, self).changelist_view(request, extra_context)
\ No newline at end of file
+        return super(ThumbAdmin, self).changelist_view(request, extra_context)
+
+    class Media:
+        css = {
+            'all': ('thumb.css',),
+        }
\ No newline at end of file
